Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateKubernetesArtifacts ¶ added in v0.2.0
Generate Kubernetes Artifacts and either writes to file or uses kubectl to deploy. TODO: Refactor into two separate functions (remove `generate bool`).
func GetAllYAMLFiles ¶
GetAllYAMLFiles if path in argument is directory get all *.yml and *.yaml files in that directory. If path is file just add it to output list as it is.
func SubstituteVariables ¶ added in v0.3.0
SubstituteVariables handles environment variable substitution Expression [[ NAME ]] or [[NAME]] is used for defining variables. [[NAME]] will be replaced with the value from NAME environment variable. Returns new byte array with all variables replaced with values. If no matching variable is found, an error is raised.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.