cmd

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 18, 2017 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateKubernetesArtifacts added in v0.2.0

func CreateKubernetesArtifacts(paths []string, generate bool, args ...string) error

Generate Kubernetes Artifacts and either writes to file or uses kubectl to deploy. TODO: Refactor into two separate functions (remove `generate bool`).

func GetAllYAMLFiles

func GetAllYAMLFiles(paths []string) ([]string, error)

GetAllYAMLFiles if path in argument is directory get all *.yml and *.yaml files in that directory. If path is file just add it to output list as it is.

Types

This section is empty.

Jump to