Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateKubernetesArtifacts ¶ added in v0.2.0
Generate Kubernetes Artifacts and either writes to file or uses kubectl to deploy. TODO: Refactor into two separate functions (remove `generate bool`).
func GetAllYAMLFiles ¶
GetAllYAMLFiles if path in argument is directory get all *.yml and *.yaml files in that directory. If path is file just add it to output list as it is.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.