spec

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2017 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	Name                       string            `json:"name"`
	Labels                     map[string]string `json:"labels,omitempty"`
	VolumeClaims               []VolumeClaim     `json:"volumeClaims,omitempty"`
	ConfigMaps                 []ConfigMapMod    `json:"configMaps,omitempty"`
	Services                   []ServiceSpecMod  `json:"services,omitempty"`
	Ingresses                  []IngressSpecMod  `json:"ingresses,omitempty"`
	Secrets                    []SecretMod       `json:"secrets,omitempty"`
	ExtraResources             []string          `json:"extraResources,omitempty"`
	PodSpecMod                 `json:",inline"`
	ext_v1beta1.DeploymentSpec `json:",inline"`
}

type ConfigMapMod

type ConfigMapMod struct {
	Name string            `json:"name,omitempty"`
	Data map[string]string `json:"data,omitempty"`
}

type Container

type Container struct {
	// one common definitions for livenessProbe and readinessProbe
	// this allows to have only one place to define both probes (if they are the same)
	Health           *api_v1.Probe `json:"health,omitempty"`
	api_v1.Container `json:",inline"`
}

type Controller

type Controller struct {
	Controller string `json:"controller,omitempty"`
}

type IngressSpecMod

type IngressSpecMod struct {
	Name                    string `json:"name"`
	ext_v1beta1.IngressSpec `json:",inline"`
}

type PodSpecMod

type PodSpecMod struct {
	Containers     []Container `json:"containers,conflicting,omitempty"`
	InitContainers []Container `json:"initContainers,conflicting,omitempty"`
	api_v1.PodSpec `json:",inline"`
}

type SecretMod

type SecretMod struct {
	Name          string `json:"name,omitempty"`
	api_v1.Secret `json:",inline"`
}

type ServicePortMod

type ServicePortMod struct {
	api_v1.ServicePort `json:",inline"`
	// Endpoint allows specifying an ingress resource in the format
	// `<Host>/<Path>`
	Endpoint string `json:"endpoint"`
}

type ServiceSpecMod

type ServiceSpecMod struct {
	api_v1.ServiceSpec `json:",inline"`
	Name               string           `json:"name,omitempty"`
	Ports              []ServicePortMod `json:"ports,conflicting"`
}

type VolumeClaim

type VolumeClaim struct {
	api_v1.PersistentVolumeClaimSpec `json:",inline"`
	Name                             string `json:"name"`
	Size                             string `json:"size"`
}

Jump to